summaryrefslogtreecommitdiff
path: root/util/lxbios/input_file.c
diff options
context:
space:
mode:
authorStefan Reinauer <stepan@coresystems.de>2008-01-18 15:33:49 +0000
committerStefan Reinauer <stepan@openbios.org>2008-01-18 15:33:49 +0000
commitf527e70333e9644f4024737240b9be18f4e2d4d4 (patch)
tree9a6fa00b8e6cebf0102d6f2f985097fa754723fd /util/lxbios/input_file.c
parent8df401db3bb6419c8fc9339dcc505332dff33bfe (diff)
rename linuxbios -> coreboot
Signed-off-by: Stefan Reinauer <stepan@coresystems.de> Acked-by: Stefan Reinauer <stepan@coresystems.de> git-svn-id: svn://svn.coreboot.org/coreboot/trunk@3055 2b7e53f0-3cfb-0310-b3e9-8179ed1497e1
Diffstat (limited to 'util/lxbios/input_file.c')
-rw-r--r--util/lxbios/input_file.c22
1 files changed, 11 insertions, 11 deletions
diff --git a/util/lxbios/input_file.c b/util/lxbios/input_file.c
index fd60c063e0..cfe79315e9 100644
--- a/util/lxbios/input_file.c
+++ b/util/lxbios/input_file.c
@@ -8,8 +8,8 @@
* UCRL-CODE-2003-012
* All rights reserved.
*
* This file is part of lxbios, a utility for reading/writing LinuxBIOS
* parameters and displaying information from the LinuxBIOS table.
* For details, see <http://www.llnl.gov/linux/lxbios/>.
*
* Please also read the file DISCLAIMER which is included in this software
@@ -56,7 +56,7 @@ static const char blank_or_comment_regex[] =
const char assignment_regex[] =
/* optional whitespace */
"^[[:space:]]*"
/* followed by a LinuxBIOS parameter name */
"([^[:space:]]+)"
/* followed by optional whitespace */
"[[:space:]]*"
@@ -120,7 +120,7 @@ cmos_write_t * process_input_file (FILE *f)
name = &line[match[1].rm_so];
value = &line[match[2].rm_so];
/* now look up the LinuxBIOS parameter name */
if (is_checksum_name(name) || (e = find_cmos_entry(name)) == NULL)
{ fprintf(stderr, "%s: Error on line %d of input file: CMOS parameter "
"%s not found.\n", prog_name, line_num, name);
@@ -224,7 +224,7 @@ static unsigned long long try_prepare_cmos_write (const cmos_entry_t *e,
case CMOS_OP_NEGATIVE_INT:
fprintf(stderr, "%s: Error on line %d of input file: This program "
"does not support assignment of negative numbers to "
- "LinuxBIOS parameters.", prog_name, line_num);
+ "coreboot parameters.", prog_name, line_num);
break;
case CMOS_OP_INVALID_INT:
@@ -234,7 +234,7 @@ static unsigned long long try_prepare_cmos_write (const cmos_entry_t *e,
case CMOS_OP_RESERVED:
fprintf(stderr, "%s: Error on line %d of input file: Can not modify "
- "reserved LinuxBIOS parameter %s.", prog_name, line_num,
+ "reserved coreboot parameter %s.", prog_name, line_num,
e->name);
break;
@@ -245,32 +245,32 @@ static unsigned long long try_prepare_cmos_write (const cmos_entry_t *e,
break;
case CMOS_OP_NO_MATCHING_ENUM:
- fprintf(stderr, "%s: LinuxBIOS parameter %s has no matching enums.",
+ fprintf(stderr, "%s: coreboot parameter %s has no matching enums.",
prog_name, e->name);
break;
case CMOS_AREA_OUT_OF_RANGE:
fprintf(stderr, "%s: The CMOS area specified by the layout info for "
- "LinuxBIOS parameter %s is out of range.", prog_name,
+ "coreboot parameter %s is out of range.", prog_name,
e->name);
break;
case CMOS_AREA_OVERLAPS_RTC:
fprintf(stderr, "%s: The CMOS area specified by the layout info for "
- "LinuxBIOS parameter %s overlaps the realtime clock area.",
+ "coreboot parameter %s overlaps the realtime clock area.",
prog_name, e->name);
break;
case CMOS_AREA_TOO_WIDE:
fprintf(stderr, "%s: The CMOS area specified by the layout info for "
- "LinuxBIOS parameter %s is too wide.",
+ "coreboot parameter %s is too wide.",
prog_name, e->name);
break;
default:
fprintf(stderr,
"%s: Unknown error encountered while attempting to modify "
- "LinuxBIOS parameter %s.", prog_name, e->name);
+ "coreboot parameter %s.", prog_name, e->name);
break;
}
@@ -8,8 +8,8 @@
* All rights reserved.
*
- * This file is part of lxbios, a utility for reading/writing LinuxBIOS
- * parameters and displaying information from the LinuxBIOS table.
+ * This file is part of lxbios, a utility for reading/writing coreboot
+ * parameters and displaying information from the coreboot table.
* For details, see <http://www.llnl.gov/linux/lxbios/>.
*
@@ -56,7 +56,7 @@ static const char blank_or_comment_regex[] =
/* optional whitespace */
"^[[:space:]]*"
- /* followed by a LinuxBIOS parameter name */
+ /* followed by a coreboot parameter name */
"([^[:space:]]+)"
/* followed by optional whitespace */
@@ -120,7 +120,7 @@ cmos_write_t * process_input_file (FILE *f)
name = &line[match[1].rm_so];
value = &line[match[2].rm_so];
- /* now look up the LinuxBIOS parameter name */
+ /* now look up the coreboot parameter name */
if (is_checksum_name(name) || (e = find_cmos_entry(name)) == NULL)
{ fprintf(stderr, "%s: Error on line %d of input file: CMOS parameter "